@@ -23,16 +23,31 @@ pqxx::Cursor::Cursor(pqxx::TransactionItf &T,
 		     const string &BaseName,
 		     size_type Count) :
   m_Trans(T),
-  m_Name(BaseName),
+  m_Name(),
   m_Count(Count),
   m_Done(false),
   m_Pos(pos_start),
   m_Size(pos_unknown)
 {
   // Give ourselves a locally unique name based on connection name
-  m_Name += "_" + T.Name() + "_" + ToString(T.GetUniqueCursorNum());
+  m_Name += "\"" + 
+            BaseName + "_" + T.Name() + "_" + ToString(T.GetUniqueCursorNum()) +
+	    "\"";
 
-  m_Trans.Exec("DECLARE \"" + m_Name + "\" CURSOR FOR " + Query);
+  m_Trans.Exec("DECLARE " + m_Name + " CURSOR FOR " + Query);
+}
+
+
+pqxx::Cursor::Cursor(pqxx::TransactionItf &T,
+    	             const Result::Field &Name,
+		     size_type Count) :
+  m_Trans(T),
+  m_Name(Name.c_str()),
+  m_Count(Count),
+  m_Done(false),
+  m_Pos(pos_unknown),
+  m_Size(pos_unknown)
+{
 }
 
 
@@ -87,7 +102,7 @@ pqxx::Result::size_type pqxx::Cursor::Move(size_type Count)
   if ((Count < 0) && (m_Pos == pos_start)) return 0;
 
   m_Done = false;
-  const string Cmd( "MOVE " + OffsetString(Count) + " IN \"" + m_Name + "\"");
+  const string Cmd( "MOVE " + OffsetString(Count) + " IN " + m_Name);
   long int A = 0;
 
   try
@@ -216,7 +231,7 @@ string pqxx::Cursor::OffsetString(size_type Count)
 
 string pqxx::Cursor::MakeFetchCmd(size_type Count) const
 {
-  return "FETCH " + OffsetString(Count) + " IN \"" + m_Name + "\"";
+  return "FETCH " + OffsetString(Count) + " IN " + m_Name;
 }
 
 
